developerscripttools.AbjUpScript
================================

.. abjad-lineage:: abjad.tools.developerscripttools.AbjUpScript.AbjUpScript.AbjUpScript

.. autoclass:: abjad.tools.developerscripttools.AbjUpScript.AbjUpScript.AbjUpScript
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.developerscripttools.AbjUpScript.AbjUpScript.AbjUpScript.alias
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.AbjUpScript.AbjUpScript.AbjUpScript.argument_parser
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.AbjUpScript.AbjUpScript.AbjUpScript.formatted_help
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.AbjUpScript.AbjUpScript.AbjUpScript.formatted_usage
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.AbjUpScript.AbjUpScript.AbjUpScript.formatted_version
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.AbjUpScript.AbjUpScript.AbjUpScript.long_description
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.AbjUpScript.AbjUpScript.AbjUpScript.program_name
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.AbjUpScript.AbjUpScript.AbjUpScript.scripting_group
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.AbjUpScript.AbjUpScript.AbjUpScript.short_description
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.AbjUpScript.AbjUpScript.AbjUpScript.storage_format
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.AbjUpScript.AbjUpScript.AbjUpScript.version
   :noindex:

Methods
-------

.. automethod:: abjad.tools.developerscripttools.AbjUpScript.AbjUpScript.AbjUpScript.process_args
   :noindex:

.. automethod:: abjad.tools.developerscripttools.AbjUpScript.AbjUpScript.AbjUpScript.setup_argument_parser
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.developerscripttools.AbjUpScript.AbjUpScript.AbjUpScript.__call__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.AbjUpScript.AbjUpScript.AbjUpScript.__eq__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.AbjUpScript.AbjUpScript.AbjUpScript.__ge__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.AbjUpScript.AbjUpScript.AbjUpScript.__gt__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.AbjUpScript.AbjUpScript.AbjUpScript.__le__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.AbjUpScript.AbjUpScript.AbjUpScript.__lt__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.AbjUpScript.AbjUpScript.AbjUpScript.__ne__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.AbjUpScript.AbjUpScript.AbjUpScript.__repr__
   :noindex:
